package cz.upol.db;

import java.sql.Connection;
import java.sql.DatabaseMetaData;
import java.sql.DriverManager;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.sql.Statement;

public class EmployeeExample {
	
	public static void main(String[] args) throws Exception {
		try (Connection con = DriverManager.getConnection("jdbc:derby:demo;create=true")) {		
			prepareDB(con);
			doSomething(con);
		}
	}

	private static void doSomething(Connection con) throws EmployeeDBException {
		try (EmployeeManager employeeManager = new EmployeeManager(con)) {
			Employee emp1 = employeeManager.create("William Riker", 30, 70000);
			System.out.println("Employee No. 1:" + emp1);
			
			employeeManager.create("Miles O'Brien", 40, 20000);
			employeeManager.create("Deana Troi", 35, 20000);
			employeeManager.create("Wesley Crusher", 15, 0);
			employeeManager.create("Beverly Crusher", 35, 34000);
			
			listAllEmployees(employeeManager);
			
			emp1.setSalary(0);
			employeeManager.commitChanges(emp1);
			
			listAllEmployees(employeeManager);
			
			Employee emp = employeeManager.getByName("Wesley Crusher");
			employeeManager.remove(emp1);
			employeeManager.remove(emp);
			
			listAllEmployees(employeeManager);
		}
	}
	
	private static void listAllEmployees(EmployeeManager employeeManager) throws EmployeeDBException {
		System.out.println("Employees:");
		for (String empName : employeeManager.getEmployeeNames()) {
			Employee emp = employeeManager.getByName(empName);
			System.out.println(emp);
		}
	}
	
	/**
	 * Inicializuje tabulky v databazi
	 * @throws SQLException 
	 */
	private static void prepareDB(Connection con) throws SQLException {
		try (Statement stmt = con.createStatement()) {
			if (!isReady(con, "EMPLOYEES")) {
				stmt.executeUpdate("CREATE TABLE employees (name VARCHAR(50) PRIMARY KEY, salary int, age int)");
			} else {
				stmt.executeUpdate("DELETE FROM employees");
			}
		}	
	}
	
	/**
	 * Vraci true pokud databazi existuje tabulka demo 
	 */
	private static boolean isReady(Connection con, String table) throws SQLException {
		DatabaseMetaData dbm = con.getMetaData();
		try (ResultSet tables = dbm.getTables(null, null, table, null)) {
			return tables.next();
		}
	}

}
